<?php

namespace Drupal\shy_one_time;

use Drupal\Core\State\StateInterface;

/**
 * Provides a service for the Shy One Time state variables.
 */
class ShyOneTimeState implements ShyOneTimeStateInterface {

  /**
   * The state.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Constructs a new ShyOneTimeState object.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The state.
   */
  public function __construct(StateInterface $state) {
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public function getUserAgents(): array|string {
    $userAgents = $this->state->get('shy_one_time.user_agents', '');
    return explode(PHP_EOL, rtrim($userAgents));
  }

  /**
   * {@inheritdoc}
   */
  public function checkUserAgents($currentUserAgent): bool|string {

    $isBlockedUserAgent = FALSE;

    foreach ($this->getUserAgents() as $userAgent) {

      $trimmedUserAgent = preg_replace('/\s+/', ' ', trim($userAgent));
      $patternUserAgent = "/" . preg_quote($trimmedUserAgent, '/') . "/i";

      if (preg_match($patternUserAgent, $currentUserAgent)) {
        $isBlockedUserAgent = TRUE;
        break;
      }
    }

    return $isBlockedUserAgent;
  }

}
